# Tablet

Preliminary Read-me template, more info to be filled in soon

### Why you need this

You want to draw simple 2D to support MBSE schematic like drawings

### Installation

Create or use a python 3.12+ environment. Then

% pip install tabletqt

#### From your python script

You need this import statement at a minimum:

    <TBD>

#### From the command line

This is not the intended usage scenario, but may be helpful for testing or exploration. Since scrall may generate
some diagnostic info you may want to create a fresh working directory and cd into it first. From there...

    % tabletqt

You should also see a file named `tabletqt.log`